autotrait - help
================

Test that we present the trait's provided ``help``.

.. autotrait:: sample_module.SampleConfigurable.trait
   :noindex:

.. autotrait:: sample_module.TraitTypesSampleConfigurable.trait_integer
   :noindex:

.. autotrait:: sample_module.TraitTypesSampleConfigurable.trait_unicode
   :noindex:

.. autotrait:: sample_module.TraitTypesSampleConfigurable.trait_dict
   :noindex:

.. autotrait:: sample_module.TraitTypesSampleConfigurable.trait_instance
   :noindex:

.. autotrait:: sample_module.TraitTypesSampleConfigurable.trait_union
   :noindex:
